@@ -4,12 +4,11 @@ mod metadata;
 mod target_type;
 mod welcome_screen;
 
-#[allow(deprecated)]
 pub use self::{
     channel::InviteChannel,
     guild::InviteGuild,
     metadata::InviteMetadata,
-    target_type::{TargetType, TargetUserType},
+    target_type::TargetType,
     welcome_screen::{WelcomeScreen, WelcomeScreenChannel},
 };
 
